summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/rc/openrc-run.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/rc/openrc-run.c b/src/rc/openrc-run.c
index 989779bb..6e7b7e76 100644
--- a/src/rc/openrc-run.c
+++ b/src/rc/openrc-run.c
@@ -939,9 +939,9 @@ svc_stop_real(void)
{
bool stopped;
/* If we're stopping localmount, set LC_ALL=C so that
* bash doesn't load anything blocking the unmounting of /usr */
- if (strcmp(applet, "localmount") == 0)
+ if (strncmp(applet, "mount.", 6) == 0)
setenv("LC_ALL", "C", 1);
if (ibsave)
@@ -939,9 +939,9 @@ svc_stop_real(void)
{
bool stopped;
- /* If we're stopping localmount, set LC_ALL=C so that
+ /* If we're stopping mount.*, set LC_ALL=C so that
* bash doesn't load anything blocking the unmounting of /usr */